
A brick_wall_build  Python build.
=================================

A build system for data science tasks.

License
-------

brick_wall_build is licensed under a `MIT
license <http://opensource.org/licenses/MIT>`_
